@@ -10,6 +10,15 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Date:" : "Data :",
     "Where:" : "Ont :",
+    "Anniversary" : "Anniversari",
+    "Appointment" : "Rendetz-vos",
+    "Business" : "Afar",
+    "Education" : "Educacion",
+    "Holiday" : "Vacanças",
+    "Meeting" : "Reünion",
+    "Personal" : "Personal",
+    "Travel" : "Viatge",
+    "Vacation" : "Vacanças",
     "A Calendar app for Nextcloud" : "Una aplicacion de calendièr per Nextcloud",
     "Previous day" : "Jorn passat",
     "Previous week" : "Setmana passada",
@@ -17,11 +26,11 @@ OC.L10N.register(
     "Next day" : "Jorn seguent",
     "Next week" : "Setmana seguenta",
     "Next month" : "Mes seguent",
-    "New event" : "Eveniment novèl",
     "Today" : "Uèi",
     "Day" : "Jorn",
     "Week" : "Aquesta setmana",
     "Month" : "Mes",
+    "Year" : "Annada",
     "List" : "Tièra",
     "Preview" : "Apercebut",
     "Copy link" : "Copiar lo ligam",
@@ -133,7 +142,6 @@ OC.L10N.register(
     "Type to search time zone" : "Picar per cercar un fus orari",
     "Global" : "Global",
     "Subscribe" : "S'abonar",
-    "Personal" : "Personal",
     "Create a new event" : "Crear un eveniment novèl",
     "[Today]" : "[Uèi]",
     "[Tomorrow]" : "[Deman]",
@@ -142,14 +150,6 @@ OC.L10N.register(
     "Details" : "Detalhs",
     "Attendees" : "Convidats",
     "Close" : "Tampar",
-    "Anniversary" : "Anniversari",
-    "Appointment" : "Rendetz-vos",
-    "Business" : "Afar",
-    "Education" : "Educacion",
-    "Holiday" : "Vacanças",
-    "Meeting" : "Reünion",
-    "Travel" : "Viatge",
-    "Vacation" : "Vacanças",
     "Daily" : "Cada jorn",
     "Weekly" : "Cada setmana",
     "Monthly" : "Cada mes",
